@@ -84,9 +84,9 @@ class FilterStructs( object ):
                     or_filters = []
 
                     for match in value:
-                        or_filters.append( '{0}:{1}'.format( key, match ))
+                        or_filters.append( '"{0}"'.format( match ))
 
-                    and_filters.append( '( {0} )'.format( ' OR '.join( or_filters )))
+                    and_filters.append( '({0}:({1}))'.format( key, ' OR '.join( or_filters )))
             else:
                 and_filters.append( '{0}:{1}'.format( key, value ))
 
